@@ -2,7 +2,7 @@
 
 ################################################################################
 ###                                                                          ###
-### Created by Martin Genet, 2012-2021                                       ###
+### Created by Martin Genet, 2012-2022                                       ###
 ###                                                                          ###
 ### University of California at San Francisco (UCSF), USA                    ###
 ### Swiss Federal Institute of Technology (ETH), Zurich, Switzerland         ###
@@ -10,11 +10,8 @@
 ###                                                                          ###
 ################################################################################
 
-from builtins import range
-
-import dolfin
-import glob
 import numpy
+import random
 import vtk
 
 import myPythonLibrary    as mypy
@@ -32,47 +29,48 @@ def compute_warped_images(
         ref_image=None,
         ref_image_folder=None,
         ref_image_basename=None,
-        ref_image_model=None,
+        ref_image_ext="vti",
         ref_frame=0,
+        ref_image_model=None,
+        noise_params={},
         suffix="warped",
         print_warped_mesh=0,
         verbose=0):
 
     assert ((ref_image is not None)
-         or ((ref_image_folder is not None)
+         or ((ref_image_folder   is not None)
          and (ref_image_basename is not None))), "Must provide a ref_image or a ref_image_folder and a ref_image_basename. Aborting."
 
     if (ref_image is None):
-        ref_image_zfill = len(glob.glob(ref_image_folder+"/"+ref_image_basename+"_*.vti")[0].rsplit("_")[-1].split(".")[0])
-        ref_image_filename = ref_image_folder+"/"+ref_image_basename+"_"+str(ref_frame).zfill(ref_image_zfill)+".vti"
-        ref_image = myvtk.readImage(
-            filename=ref_image_filename)
+        ref_images_series = dwarp.ImagesSeries(
+            folder=ref_image_folder,
+            basename=ref_image_basename,
+            ext=ref_image_ext)
+        ref_image = ref_images_series.get_image(k_frame=ref_frame)
 
     if (ref_image_model is None):
         ref_image_interpolator = myvtk.getImageInterpolator(
             image=ref_image)
 
-    image = vtk.vtkImageData()
-    image.SetOrigin(ref_image.GetOrigin())
-    image.SetSpacing(ref_image.GetSpacing())
-    image.SetExtent(ref_image.GetExtent())
-    if (vtk.vtkVersion.GetVTKMajorVersion() >= 6):
-        image.AllocateScalars(vtk.VTK_FLOAT, 1)
-    else:
-        image.SetScalarTypeToFloat()
-        image.SetNumberOfScalarComponents(1)
-        image.AllocateScalars()
+    noise = dwarp.Noise(
+        params=noise_params)
+
+    image = myvtk.createImage(
+        origin=ref_image.GetOrigin(),
+        spacing=ref_image.GetSpacing(),
+        extent=ref_image.GetExtent())
     scalars = image.GetPointData().GetScalars()
 
-    working_zfill = len(glob.glob(working_folder+"/"+working_basename+"_*."+working_ext)[0].rsplit("_")[-1].split(".")[0])
-    n_frames = len(glob.glob(working_folder+"/"+working_basename+"_"+"[0-9]"*working_zfill+"."+working_ext))
-    # n_frames = 1
+    working_series = dwarp.MeshesSeries(
+        folder=working_folder,
+        basename=working_basename,
+        ext=working_ext)
 
     if   (working_ext == "vtk"):
         reader = vtk.vtkUnstructuredGridReader()
     elif (working_ext == "vtu"):
         reader = vtk.vtkXMLUnstructuredGridReader()
-    reader.UpdateDataObject();
+    reader.UpdateDataObject()
     ugrid = reader.GetOutput()
 
     warp = vtk.vtkWarpVector()
@@ -98,14 +96,15 @@ def compute_warped_images(
     x = numpy.empty(3)
     I = numpy.empty(1)
     m = numpy.empty(1)
-    for k_frame in range(n_frames):
+    for k_frame in range(working_series.n_frames):
         mypy.my_print(verbose, "k_frame = "+str(k_frame))
 
-        reader.SetFileName(working_folder+"/"+working_basename+"_"+str(k_frame).zfill(working_zfill)+"."+working_ext)
+        reader.SetFileName(working_series.get_mesh_filename(k_frame=k_frame))
         reader.Update()
         # print(ugrid)
 
-        assert (ugrid.GetPointData().HasArray(working_displacement_field_name)), "no array '" + working_displacement_field_name + "' in ugrid"
+        assert (ugrid.GetPointData().HasArray(working_displacement_field_name)),\
+            "no array '" + working_displacement_field_name + "' in ugrid. Aborting."
         ugrid.GetPointData().SetActiveVectors(working_displacement_field_name)
         warp.Update()
         probe.Update()
@@ -114,10 +113,10 @@ def compute_warped_images(
         if (print_warped_mesh):
             myvtk.writeUGrid(
                 ugrid=warped_ugrid,
-                filename=working_folder+"/"+working_basename+"-warped_"+str(k_frame).zfill(working_zfill)+"."+working_ext)
+                filename=working_series.get_mesh_filename(k_frame=k_frame, suffix="warped"))
         #myvtk.writeImage(
             #image=probed_image,
-            #filename=working_folder+"/"+working_basename+"_"+str(k_frame).zfill(working_zfill)+".vti")
+            #filename=working_series.get_mesh_filename(k_frame=k_frame, ext="vti"))
 
         for k_point in range(image.GetNumberOfPoints()):
             scalars_mask.GetTuple(k_point, m)
@@ -131,8 +130,9 @@ def compute_warped_images(
                     ref_image_interpolator.Interpolate(X, I)
                 else:
                     I[0] = ref_image_model(X)
+            noise.add_noise(I)
             scalars.SetTuple(k_point, I)
 
         myvtk.writeImage(
             image=image,
-            filename=working_folder+"/"+working_basename+("-"+suffix)*(suffix!="")+"_"+str(k_frame).zfill(working_zfill)+".vti")
+            filename=working_series.get_mesh_filename(k_frame=k_frame, suffix=suffix, ext="vti"))
